@@ -1,26 +1,28 @@
 package org.gcube.portlets.user.td.gwtservice.shared.tr.metadata;
 
+import java.util.Date;
+
 
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  */
 public class TRValidSinceMetadata implements TRMetadata {
 	
 	private static final long serialVersionUID = 5425320654892310426L;
-	String id="ValidSinceMetadata";
-	String title="Valid Since";
+	private String id="ValidSinceMetadata";
+	private String title="Valid Since";
 	
-	private String value;
+	private Date value;
 
-	public String getValue() {
+	public Date getValue() {
 		return value;
 	}
 
-	public void setValue(String value) {
+	public void setValue(Date value) {
 		this.value = value;
 	}
 
